@@ -19,7 +19,8 @@ from django import VERSION as DJANGO_VERSION
 from django.conf import settings
 from django.http import HttpResponse, QueryDict
 from django.utils.decorators import classonlymethod
-from eggplant.constants import HTTP_METHOD, SETTINGS_HTTPS_ONLY
+from eggplant.constants import HTTP_METHOD
+from eggplant.constants.settings import HTTPS_ONLY
 from eggplant.views.exceptions import ViewError
 
 class View(object):
@@ -55,7 +56,7 @@ class View(object):
         # Go
         try:
             # HTTPS?
-            if getattr(settings, SETTINGS_HTTPS_ONLY, False) and not self.request.is_secure():
+            if getattr(settings, HTTPS_ONLY, False) and not self.request.is_secure():
                 raise ViewError(400, 'This url accepts HTTPS only.')
 
             # Check allowed http methods
